==> eiffelstudio-18.01.10.1424.tar: F_code/C9/be444.c <==
/*
 * Code for class BENCH_WIZARD_MANAGER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "be444.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {BENCH_WIZARD_MANAGER}.make_and_launch */
#undef EIF_VOLATILE
#define EIF_VOLATILE volatile
void F1073_9220 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTED;
	EIF_BOOLEAN EIF_VOLATILE loc1 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE EIF_VOLATILE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE EIF_VOLATILE saved_except = (EIF_REFERENCE) 0;
	EIF_REFERENCE  EIF_VOLATILE tr1 = NULL;
	RTLD;
	RTXD;
	
	RTLI(4);
	RTLR(0,loc2);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLR(3,saved_except);
	RTLIU(4);
	RTXSLS;
	
	RTEAA("make_and_launch", 1072, Current, 2, 0, 15587);
	RTGC;
	RTE_T
	RTHOOK(1);
	if ((EIF_BOOLEAN) !loc1) {
		RTHOOK(2);
		tr1 = RTLNS(eif_new_type(1386, 0x00).id, 1386, _OBJSIZ_0_3_0_0_0_0_0_0_);
		loc2 = (EIF_REFERENCE) tr1;
		RTHOOK(3);
		F1385_13750(RTCW(loc2));
		RTHOOK(4);
		F474_4186(Current, loc2);
		RTHOOK(5);
		F1072_9216(Current);
	} else {
		RTHOOK(6);
		F627_4948(Current);
	}
	RTE_E
	RTXSC;
	RTHOOK(7);
	loc1 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(8);
	RTER;
	/* NOTREACHED */
	RTE_EE
	RTHOOK(9);
	RTEOK;
	RTLE;
}
#undef EIF_VOLATILE
#define EIF_VOLATILE

/* {BENCH_WIZARD_MANAGER}.prepare */
#undef EIF_VOLATILE
#define EIF_VOLATILE volatile
void F1073_9221 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTED;
	EIF_REFERENCE EIF_VOLATILE loc1 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN EIF_VOLATILE loc2 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE EIF_VOLATILE saved_except = (EIF_REFERENCE) 0;
	EIF_REFERENCE  EIF_VOLATILE tr1 = NULL;
	EIF_REFERENCE  EIF_VOLATILE tr2 = NULL;
	RTLD;
	RTXD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLR(4,saved_except);
	RTLIU(5);
	RTXSLS;
	
	RTEAA("prepare", 1072, Current, 2, 0, 15588);
	RTGC;
	RTE_T
	RTHOOK(1);
	if ((EIF_BOOLEAN) !loc2) {
		RTHOOK(2);
		F1073_9222(Current);
		RTHOOK(3);
		F1072_9217(Current);
		RTHOOK(4);
		tr1 = RTLNS(eif_new_type(1122, 0x00).id, 1122, _OBJSIZ_6_3_0_1_0_0_0_0_);
		F1056_8916(RTCW(tr1));
		loc1 = (EIF_REFERENCE) tr1;
		RTHOOK(5);
		tr1 = RTOSCF(4956,F628_4956,(Current));
		tr2 = RTMS_EX_H("wizard.png",10,1759219815);
		tr1 = F893_7104(RTCW(tr1), tr2);
		F1123_9851(RTCW(loc1), tr1);
		RTHOOK(6);
		tr1 = F628_4951(Current);
		F1110_9706(RTCW(tr1), loc1);
	}
	RTE_E
	RTXSC;
	RTHOOK(7);
	loc2 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(8);
	RTER;
	/* NOTREACHED */
	RTE_EE
	RTHOOK(9);
	RTEOK;
	RTLE;
}
#undef EIF_VOLATILE
#define EIF_VOLATILE

/* {BENCH_WIZARD_MANAGER}.setup_locale */
void F1073_9222 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLR(3,tr2);
	RTLR(4,loc2);
	RTLIU(5);
	
	RTEAA("setup_locale", 1072, Current, 2, 0, 15589);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(1367, 0x00).id, 1367, _OBJSIZ_2_0_0_0_0_0_0_0_);
	tr2 = RTOSCF(13784,F1385_13784,(RTCV(F474_4187(Current))));
	tr2 = F893_7116(RTCW(tr2));
	F1368_13362(RTCW(tr1), tr2);
	loc1 = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	if ((EIF_BOOLEAN) ((EIF_INTEGER_32) eif_builtin_ARGUMENTS_32_argument_count (Current) >= ((EIF_INTEGER_32) 2L))) {
		RTHOOK(3);
		tr1 = RTLNS(eif_new_type(1366, 0x00).id, 1366, _OBJSIZ_6_0_0_0_0_0_0_0_);
		tr2 = F626_4925(Current, ((EIF_INTEGER_32) 2L));
		F1367_13351(RTCW(tr1), tr2);
		loc2 = F1368_13363(RTCW(loc1), tr1);
	}
	RTHOOK(4);
	tr1 = RTOSCF(4987,F628_4987,(Current));
	F217_3375(RTCW(tr1), loc2);
	RTHOOK(5);
	RTLE;
	RTEE;
}

void EIF_Minit444 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.11.10.2592.tar: F_code/C9/be444.c <==
/*
 * Code for class BENCH_WIZARD_MANAGER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "be444.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {BENCH_WIZARD_MANAGER}.make_and_launch */
#undef EIF_VOLATILE
#define EIF_VOLATILE volatile
void F1076_9277 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTED;
	EIF_BOOLEAN EIF_VOLATILE loc1 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE EIF_VOLATILE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE EIF_VOLATILE saved_except = (EIF_REFERENCE) 0;
	EIF_REFERENCE  EIF_VOLATILE tr1 = NULL;
	RTLD;
	RTXD;
	
	RTLI(4);
	RTLR(0,loc2);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLR(3,saved_except);
	RTLIU(4);
	RTXSLS;
	
	RTEAA("make_and_launch", 1075, Current, 2, 0, 15690);
	RTGC;
	RTE_T
	RTHOOK(1);
	if ((EIF_BOOLEAN) !loc1) {
		RTHOOK(2);
		tr1 = RTLNS(eif_new_type(1389, 0x00).id, 1389, _OBJSIZ_0_3_0_0_0_0_0_0_);
		loc2 = (EIF_REFERENCE) tr1;
		RTHOOK(3);
		F1388_13812(RTCW(loc2));
		RTHOOK(4);
		F264_4018(Current, loc2);
		RTHOOK(5);
		F1075_9273(Current);
	} else {
		RTHOOK(6);
		F319_4673(Current);
	}
	RTE_E
	RTXSC;
	RTHOOK(7);
	loc1 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(8);
	RTER;
	/* NOTREACHED */
	RTE_EE
	RTHOOK(9);
	RTEOK;
	RTLE;
}
#undef EIF_VOLATILE
#define EIF_VOLATILE

/* {BENCH_WIZARD_MANAGER}.prepare */
#undef EIF_VOLATILE
#define EIF_VOLATILE volatile
void F1076_9278 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTED;
	EIF_REFERENCE EIF_VOLATILE loc1 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN EIF_VOLATILE loc2 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE EIF_VOLATILE saved_except = (EIF_REFERENCE) 0;
	EIF_REFERENCE  EIF_VOLATILE tr1 = NULL;
	EIF_REFERENCE  EIF_VOLATILE tr2 = NULL;
	RTLD;
	RTXD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLR(4,saved_except);
	RTLIU(5);
	RTXSLS;
	
	RTEAA("prepare", 1075, Current, 2, 0, 15691);
	RTGC;
	RTE_T
	RTHOOK(1);
	if ((EIF_BOOLEAN) !loc2) {
		RTHOOK(2);
		F1076_9279(Current);
		RTHOOK(3);
		F1075_9274(Current);
		RTHOOK(4);
		tr1 = RTLNS(eif_new_type(1125, 0x00).id, 1125, _OBJSIZ_6_3_0_1_0_0_0_0_);
		F1059_8973(RTCW(tr1));
		loc1 = (EIF_REFERENCE) tr1;
		RTHOOK(5);
		tr1 = RTOSCF(2355,F104_2355,(Current));
		tr2 = RTMS_EX_H("wizard.png",10,1759219815);
		tr1 = F896_7161(RTCW(tr1), tr2);
		F1126_9910(RTCW(loc1), tr1);
		RTHOOK(6);
		tr1 = F104_2350(Current);
		F1113_9765(RTCW(tr1), loc1);
	}
	RTE_E
	RTXSC;
	RTHOOK(7);
	loc2 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(8);
	RTER;
	/* NOTREACHED */
	RTE_EE
	RTHOOK(9);
	RTEOK;
	RTLE;
}
#undef EIF_VOLATILE
#define EIF_VOLATILE

/* {BENCH_WIZARD_MANAGER}.setup_locale */
void F1076_9279 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLR(3,tr2);
	RTLR(4,loc2);
	RTLIU(5);
	
	RTEAA("setup_locale", 1075, Current, 2, 0, 15692);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(1370, 0x00).id, 1370, _OBJSIZ_2_0_0_0_0_0_0_0_);
	tr2 = RTOSCF(13846,F1388_13846,(RTCV(F264_4019(Current))));
	tr2 = F896_7173(RTCW(tr2));
	F1371_13424(RTCW(tr1), tr2);
	loc1 = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	if ((EIF_BOOLEAN) ((EIF_INTEGER_32) eif_builtin_ARGUMENTS_32_argument_count >= ((EIF_INTEGER_32) 2L))) {
		RTHOOK(3);
		tr1 = RTLNS(eif_new_type(1369, 0x00).id, 1369, _OBJSIZ_6_0_0_0_0_0_0_0_);
		tr2 = F318_4650(Current, ((EIF_INTEGER_32) 2L));
		F1370_13413(RTCW(tr1), tr2);
		loc2 = F1371_13425(RTCW(loc1), tr1);
	}
	RTHOOK(4);
	tr1 = RTOSCF(2386,F104_2386,(Current));
	F226_3551(RTCW(tr1), loc2);
	RTHOOK(5);
	RTLE;
	RTEE;
}

void EIF_Minit444 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
